#include <config.h>
#include <jni.h>

JNIEXPORT jint JNICALL Java_java_lang_reflect_Array_getLength
  (JNIEnv * env, jclass thisClass, jobject arr);

JNIEXPORT jobject JNICALL Java_java_lang_reflect_Array_createObjectArray
    (JNIEnv * env, jclass thisClass, jclass arrayType, jint arrayLength);
